package com.steerinfo.ems.chemicalconstituents.controller;

import com.steerinfo.ems.chemicalconstituents.mapper.ChemicalConstituentsMapper;
import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;
import com.steerinfo.ems.chemicalconstituents.model.ChemicalConstituents;
import com.steerinfo.ems.chemicalconstituents.service.IChemicalConstituentsService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * ChemicalConstituents RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-03 10:03
 * 类描述
 * 修订历史：
 * 日期：2021-12-03
 * 作者：generator
 * 参考：
 * 描述：ChemicalConstituents RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/chemicalconstituentss")
public class ChemicalConstituentsController extends BaseRESTfulController {

    @Autowired
    IChemicalConstituentsService chemicalConstituentsService;

    @Autowired
    ChemicalConstituentsMapper chemicalConstituentsMapper;

    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("chemicalconstituents:view")
    @GetMapping(value = "/")
    public RESTfulResult list(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        PageList<ChemicalConstituents> list = chemicalConstituentsService.queryForPage(parmas, pageNum, pageSize);
        return success(list);
    }

    @ApiOperation(value="获取列表", notes="分页模糊查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("chemicalconstituents:view")
    @GetMapping(value = "/like/")
    public RESTfulResult listLike(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        PageList<ChemicalConstituents> list = chemicalConstituentsService.queryLikeForPage(parmas, pageNum, pageSize);
        return success(list);
    }
    
    @ApiOperation(value="创建", notes="根据ChemicalConstituents对象创建")
    @ApiImplicitParam(name = "chemicalConstituents", value = "详细实体chemicalConstituents", required = true, dataType = "ChemicalConstituents")
    //@RequiresPermissions("chemicalconstituents:create")
    @PostMapping(value = "/")
    public RESTfulResult add(@ModelAttribute ChemicalConstituents model){
        ChemicalConstituents chemicalConstituents = chemicalConstituentsService.add(model);
        return success(chemicalConstituents);
    }

    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(name = "model", value = "详细实体chemicalConstituents的id值", required = true, dataType = "ChemicalConstituents")
    //@RequiresPermissions("chemicalconstituents:view")
    @GetMapping(value = "/getById")
    public RESTfulResult get(@ModelAttribute ChemicalConstituents model){
        ChemicalConstituents chemicalConstituents = chemicalConstituentsService.getById(model);
        return success(chemicalConstituents);
    }

    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的chemicalConstituents信息来更新详细信息")
    @ApiImplicitParam(name = "chemicalConstituents", value = "详细实体chemicalConstituents", required = true, dataType = "ChemicalConstituents")
    //@RequiresPermissions("chemicalconstituents:update")
    @PutMapping(value = "/", produces  = "application/json;charset=UTF-8")
    public RESTfulResult update(@RequestBody ChemicalConstituents model){
        ChemicalConstituents chemicalConstituents = chemicalConstituentsService.modify(model);
        return success(chemicalConstituents);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(name = "models", value = "详细实体chemicalConstituents", required = true, dataType = "ChemicalConstituents")
    //@RequiresPermissions("chemicalconstituents:delete")
    @DeleteMapping(value = "/")//ChemicalConstituents
    public RESTfulResult delete(@RequestBody List<ChemicalConstituents> models){
    	if(ListUtils.isNotEmpty(models)) {
			  chemicalConstituentsService.delete(models);
    	}
      return success();
    }
    @ApiOperation(value="获取详细信息", notes="根据url的gmid来获取详细信息")
    @ApiImplicitParam(name = "chemicalConstituents", value = "详细集合chemicalConstituents", required = true, dataType = "ChemicalConstituents")
    @GetMapping("/getDataByGmid")
    public RESTfulResult getDataByGmid(@RequestParam HashMap parmas){
        String gmid = parmas.get("gmid").toString();
        List<ChemicalConstituents> dataByGmid = chemicalConstituentsService.getDataByGmid(gmid);
        return success(dataByGmid);
    }

    @PutMapping("/update")
    public RESTfulResult update(@RequestBody ChemicalConstituents[] models){
        Map<String,Object> map = new HashMap<>();
        for (ChemicalConstituents model : models) {
            map.put("gmid",model.getGmid());
            map.put("chemCode",model.getChemCode());
            ChemicalConstituents chemicalConstituents = chemicalConstituentsMapper.selectByPrimaryKey(model);
            if (chemicalConstituents != null) {
                chemicalConstituentsMapper.updateByPrimaryKey(model);
            } else {
                chemicalConstituentsMapper.insert(model);
            }
        }
        return success();
    }

    @DeleteMapping("/delete")
    public RESTfulResult delete(@RequestBody ChemicalConstituents[] models){
        List<ChemicalConstituents> ls =  new ArrayList<>();
        for (ChemicalConstituents model : models) {
            if (model.getGmid() != null && !model.getGmid().equals("")  && model.getChemCode() != null && !model.getChemCode().equals("")){
                ls.add(model);
            }
            if(ls.size()>0) {
                chemicalConstituentsService.delete(ls);
            }
        }
        return success();
    }

}